scipy.sparse.linalg.LinearOperator
==================================

.. currentmodule:: scipy.sparse.linalg

.. autoclass:: LinearOperator

   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         LinearOperator.matmat
         LinearOperator.matvec



   

